@@ -1,17 +1,16 @@
 use strict; use warnings;
 package Swim::Util;
-use Devel::Peek;
-use utf8;
+use Encode;
 
 sub merge_meta {
     require YAML::XS;
     require Hash::Merge;
     my ($self, $meta, $yaml) = @_;
     my $data = eval {
-        YAML::XS::Load($yaml);
+        YAML::XS::Load(Encode::encode 'UTF-8', $yaml);
     };
     if ($@) {
-        warn "Swim meta failed to load";
+        warn "Swim meta failed to load:\n$@";
         $data = {};
     }
     Hash::Merge::merge($data, $meta);
@@ -21,8 +20,11 @@ sub slurp {
     my ($self, $file) = @_;
     open my $fh, $file
         or die "Can't open '$file' for input";
+    binmode($fh, ':encoding(UTF-8)');
     local $/;
-    <$fh>;
+    my $meta = <$fh>;
+    close $fh;
+    return $meta;
 }
 
 1;
